
(_api_mie)=
# Mie

## Linearized Mie
```{eval-rst}
.. autosummary::
    :toctree: generated/

    sasktran2.mie.LinearizedMie
```

## Output Data structures
```{eval-rst}
.. autosummary::
    :toctree: generated/

    sasktran2.mie.MieOutput
    sasktran2.mie.MieData

```

## Particle Size Distributions
```{eval-rst}
.. autosummary::
    :toctree: generated/

    sasktran2.mie.distribution.ParticleSizeDistribution
    sasktran2.mie.distribution.LogNormalDistribution

```

## Refractive Index Containers
```{eval-rst}
.. autosummary::
    :toctree: generated/

    sasktran2.mie.refractive.RefractiveIndex
    sasktran2.mie.refractive.H2SO4
    sasktran2.mie.refractive.Ice
    sasktran2.mie.refractive.Water
    sasktran2.mie.refractive.Dust

```
